- file
VirusHunterGatherer hittable.
- groupby
(optional): A character specifying the column containing the groups (default: "best_query").
Note: Gatherer hittables do not have a "best_query" column. Please provide an appropriate column for grouping.
- taxa_rank
(optional): When groupby is set to "ViralRefSeq_taxonomy", specify the taxonomic rank to group your data by.
Supported ranks are:
- cutoff
(optional): A numeric value representing the cutoff for the refseq E-value. Points with ViralRefSeq_E
less than or equal to this value will be colored blue; otherwise, they will be colored red (default: 1e-5).
- conlen_bubble_plot
(optional): Logical value indicating whether the contig_len column
should be used to size the bubbles in the plot. Applicable only to VirusGatherer hittables input (default: FALSE).
- contiglen_breaks
(optional): Number of breaks (default: 5) for the bubble plot (for conlen_bubble_plot=TRUE).
- theme_choice
(optional): A character indicating the ggplot2 theme to apply. Options include "minimal",
"classic", "light", "dark", "void", "grey" (or "gray"), "bw", "linedraw" (default), and "test".
Append "_dotted" to any theme to add custom dotted grid lines (e.g., "classic_dotted").
- title
(optional): The title of the plot (default: "Faceted scatter plot of viral reference E-values and sequence identity").
- title_size
(optional): The size of the title text (default: 16).
- title_face
(optional): The face (bold, italic, etc.) of the title text (default: "bold").
- title_colour
(optional): The color of the title text (default: "#2a475e").
- subtitle
(optional): The subtitle of the plot (default: NULL).
- subtitle_size
(optional): The size of the subtitle text (default: 12).
- subtitle_face
(optional): The face (bold, italic, etc.) of the subtitle text (default: "bold").
- subtitle_colour
(optional): The color of the subtitle text (default: "#1b2838").
- xlabel
(optional): The label for the x-axis (default: "Viral reference sequence identity (%)").
- ylabel
(optional): The label for the y-axis (default: "-log10 of viral reference E-values").
- axis_title_size
(optional): The size of the axis titles (default: 12).
- xtext_size
(optional): The size of the x-axis text (default: 10).
- x_angle
(optional): An integer specifying the angle (in degrees) for the x-axis text labels. Default is NULL, meaning no change.
- ytext_size
(optional): The size of the y-axis text (default: 10).
- y_angle
(optional): An integer specifying the angle (in degrees) for the y-axis text labels. Default is NULL, meaning no change.
- legend_position
(optional): The position of the legend (default: "bottom).
- legend_title_size
(optional): The size of the legend title text (default: 12).
- legend_title_face
(optional): The face (bold, italic, etc.) of the legend title text (default: "bold").
- legend_text_size
(optional): The size of the legend text (default: 10).
- true_colour
(optional): The color for points that meet the cutoff condition (default: "blue").
- false_colour
(optional): The color for points that do not meet the cutoff condition (default: "red").
- wrap_ncol
(optional): The number of columns for faceting (default: 12).
- filter_group_criteria
(optional): Character vector, numeric vector, or single character/numeric value.
Character vector: Names of viral groups to filter.
Numeric vector: Indices of viral groups to filter.
Single character or numeric value: Filter a single viral group.
NULL: No filtering is performed (default).