- vh_file
A data frame containing the Virushunter hittables results.
- groupby
(optional): A character specifying the column containing the groups (default: "best_query").
Note: Gatherer hittables do not have a "best_query" column. Please provide an appropriate column for grouping.
- taxa_rank
(optional): When groupby is set to "ViralRefSeq_taxonomy", specify the taxonomic rank to group your data by.
Supported ranks are:
- cut
(optional): A numeric value representing the cutoff for the refseq E-value (default: 1e-5).
Removes rows in file with values larger than cutoff value in "ViralRefSeq_E" column.
- title
(optional): The title of the plot (default: "Summary of unique runs by virus group").
- title_align
(optional): A character vector specifying the alignment of title (and subtitle) text.
Possible values are "left" (default), "center", or "right".
- names_
(optional): A vector of length 3 containing column names (default: c("Virus Group","Number of Unique SRA Runs","SRAs Found")).
- align
(optional): A character vector specifying the alignment of text in the table columns.
Possible values are "left" (default), "center", or "right".
- subtitle
(optional): A character specifying the subtitle of the plot (default: NULL).
- data_row.pad
(optional): Numeric value specifying the row padding (default: 6).
- column_colour
(optional): character specifying the background colour for the column header (default: "dodgerblue4").
- title_size
(optional): The size of the title text (default: 26).
- subtitle_size
(optional): Numeric specifying the size of the subtitle text (default: 14).
- title_weight
(optional): Character or numeric value specifying title font weight.
The weight of the font can be modified thorough a text-based option such as "normal", "bold" (default),
"lighter", "bolder", or, a numeric value between 1 and 1000, inclusive.
- title_colour
(optional): A character specifying the color for the title text (default: "dodgerblue4").
- table_font_size
(optional): Numeric value specifying table font size. This will change font
size for the column header and for all values in each cell (default: 14).
- cell_colour
(optional): Character specifying cell colour (default: "grey90").
- col_everyrow
(optional): Bool value specifying if every row or every second row of the table
should be filled with the colour from the cell_colour argument. col_everyrow = TRUE colors every
row and col_everyrow = FALSE (default) colors every second row.