Learn R Programming

Virusparies (version 1.1.0)

get_plot_parameters: Internal function to set default title and cutoff in boxplot function

Description

Internal function to set default title and cutoff in boxplot function

Usage

get_plot_parameters(y_column, cut)

Value

list containing cutoff and title

Arguments

y_column

y-column

cut

cutoff value